﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.Phone.Management.Deployment;
using Windows.ApplicationModel;
using CompanyHub.Utilities;

namespace CompanyHub.Models
{
public enum CompanyPackageStatus 
{
    Unknown,
    New,
    Update,
    Installed
};

    public class CompanyPackage
    {
        public string Id { get; set; }
        public string Name { get; set; }
        public string Description { get; set; }
        public string Thumbnail { get; set; }
        public string Version { get; set; }
        public Uri SourceUri { get; set; }
        public CompanyPackageStatus Status { get; set; }

        public static IEnumerable<CompanyPackage> GenerateData()
        {
            var data = new List<CompanyPackage>();

            // Get list of installed apps
            var pkgs = InstallationManager.FindPackagesForCurrentPublisher();
            
            foreach (var pkg in pkgs)
            {
                // Don't add hub app to the list
                if (pkg.Id.Name != "CompanyHub")
                {
                    // Create new CompanyPackage obj using info from Id

                    var compPkg = new CompanyPackage()
                    {
                        Id = pkg.Id.ProductId,
                        Name = pkg.Id.Name,
                        Description = "Test Description",
                        Version =  PackageVersionHelper.VersionToString(pkg.Id.Version),
                        Thumbnail = "/Assets/ApplicationIcon.png",
                        Status = CompanyPackageStatus.Unknown
                    };

                    // Create some updatable versions
                    if (data.Count() > 3)
                    {
                        compPkg.Version = "2.0.0.0";
                    }

                    data.Add(compPkg);
                }
            }

            // Add three new products
            for (int i = 7; i < 10; i++)
            {
                var compPkg = new CompanyPackage()
                {
                    Id = Guid.NewGuid().ToString(),
                    Name = "CDS APP " + i,
                    Description = "Test Description",
                    Version = "1.0.0.0",
                    Thumbnail = "/Assets/ApplicationIcon.png",
                    Status = CompanyPackageStatus.Unknown
                };

                data.Add(compPkg);
            }

            return data;
        }
    }
}
