﻿using CompanyHub.Models;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.Phone.Management.Deployment;
using CompanyHub.Utilities;

namespace CompanyHub.ViewModels
{
public class CompanyPackageViewModel : INotifyPropertyChanged
{
    private IEnumerable<CompanyPackage> _packages;

    public CompanyPackageViewModel()
    {
        LoadData();        
    }

    private void LoadData()
    {
        // Get list of packages and populate properties
        _packages = CompanyPackage.GenerateData();

        UpdatePackageStatus();

    }

public void UpdatePackageStatus()
{
    var devicePkgs = InstallationManager.FindPackagesForCurrentPublisher();

    foreach (var pkg in _packages)
    {
        var qry = devicePkgs.Where(p => p.Id.ProductId == pkg.Id);
        if (qry.Count() > 0)
        {
            var devicePkg = qry.First();
            var devicePkgVersion = PackageVersionHelper.VersionToString(devicePkg.Id.Version);

            pkg.Status = PackageVersionHelper.IsNewer(pkg.Version, devicePkgVersion) ?
                CompanyPackageStatus.Update : CompanyPackageStatus.Installed;
        }
        else
        {
            pkg.Status = CompanyPackageStatus.New;
        }

    }

    _newPackages = _packages.Where(p => p.Status == CompanyPackageStatus.New).ToList();
    _updatePackages = _packages.Where(p => p.Status == CompanyPackageStatus.Update).ToList();
    _installedPackages = _packages.Where(p => p.Status == CompanyPackageStatus.Installed).ToList();

    // Fire notifications for all properties
    NotifyPropertyChanged("NewPackages");
    NotifyPropertyChanged("UpdatePackages");
    NotifyPropertyChanged("InstalledPackages");

}

    private IEnumerable<CompanyPackage> _newPackages;
    public IEnumerable<CompanyPackage> NewPackages
    {
        get
        {
            return _newPackages;
        }
    }

    private IEnumerable<CompanyPackage> _updatePackages;
    public IEnumerable<CompanyPackage> UpdatePackages
    {
        get
        {
            return _updatePackages;
        }
    }

    private IEnumerable<CompanyPackage> _installedPackages;
    public IEnumerable<CompanyPackage> InstalledPackages
    {
        get
        {
            return _installedPackages;
        }
    }

public CompanyPackage FindPackage(string id)
{
    return _packages.Where(p => p.Id == id).FirstOrDefault();
}

    private CompanyPackage _selectedPackage;
    public CompanyPackage SelectedPackage
    {
        set
        {
            _selectedPackage = value;
            NotifyPropertyChanged("SelectedPackage");
        }
        get
        {
            return _selectedPackage;
        }
    }
    public event PropertyChangedEventHandler PropertyChanged;
    private void NotifyPropertyChanged(String propertyName)
    {
        PropertyChangedEventHandler handler = PropertyChanged;
        if (null != handler)
        {
            handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
}
